;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "eager-state" "20251221.1617"
  "Eagerly persist data onto disk."
  '((emacs "29.1")
    (llama "0.5.0"))
  :url "https://github.com/meedstrom/eager-state"
  :commit "7d34fc1f4f341a971ec165fd54b1f42eb9982971"
  :revdesc "7d34fc1f4f34"
  :keywords '("convenience")
  :authors '(("Martin Edström" . "meedstrom91@gmail.com"))
  :maintainers '(("Martin Edström" . "meedstrom91@gmail.com")))
